==> openshift-model-5.10.1-sources.jar: io/fabric8/openshift/api/model/PlatformSpecBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class PlatformSpecBuilder extends io.fabric8.openshift.api.model.PlatformSpecFluentImpl<io.fabric8.openshift.api.model.PlatformSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.PlatformSpec,io.fabric8.openshift.api.model.PlatformSpecBuilder>{
  public PlatformSpecBuilder() {
    this(false);
  }
  public PlatformSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new PlatformSpec(), validationEnabled);
  }
  public PlatformSpecBuilder(io.fabric8.openshift.api.model.PlatformSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public PlatformSpecBuilder(io.fabric8.openshift.api.model.PlatformSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new PlatformSpec(), validationEnabled);
  }
  public PlatformSpecBuilder(io.fabric8.openshift.api.model.PlatformSpecFluent<?> fluent,io.fabric8.openshift.api.model.PlatformSpec instance) {
    this(fluent, instance, false);
  }
  public PlatformSpecBuilder(io.fabric8.openshift.api.model.PlatformSpecFluent<?> fluent,io.fabric8.openshift.api.model.PlatformSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAws(instance.getAws()); 
    fluent.withAzure(instance.getAzure()); 
    fluent.withBaremetal(instance.getBaremetal()); 
    fluent.withEquinixMetal(instance.getEquinixMetal()); 
    fluent.withGcp(instance.getGcp()); 
    fluent.withIbmcloud(instance.getIbmcloud()); 
    fluent.withKubevirt(instance.getKubevirt()); 
    fluent.withOpenstack(instance.getOpenstack()); 
    fluent.withOvirt(instance.getOvirt()); 
    fluent.withType(instance.getType()); 
    fluent.withVsphere(instance.getVsphere()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public PlatformSpecBuilder(io.fabric8.openshift.api.model.PlatformSpec instance) {
    this(instance,false);
  }
  public PlatformSpecBuilder(io.fabric8.openshift.api.model.PlatformSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAws(instance.getAws()); 
    this.withAzure(instance.getAzure()); 
    this.withBaremetal(instance.getBaremetal()); 
    this.withEquinixMetal(instance.getEquinixMetal()); 
    this.withGcp(instance.getGcp()); 
    this.withIbmcloud(instance.getIbmcloud()); 
    this.withKubevirt(instance.getKubevirt()); 
    this.withOpenstack(instance.getOpenstack()); 
    this.withOvirt(instance.getOvirt()); 
    this.withType(instance.getType()); 
    this.withVsphere(instance.getVsphere()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.PlatformSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.PlatformSpec build() {
    PlatformSpec buildable = new PlatformSpec(fluent.getAws(),fluent.getAzure(),fluent.getBaremetal(),fluent.getEquinixMetal(),fluent.getGcp(),fluent.getIbmcloud(),fluent.getKubevirt(),fluent.getOpenstack(),fluent.getOvirt(),fluent.getType(),fluent.getVsphere());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PlatformSpecBuilder that = (PlatformSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-5.12.1-sources.jar: io/fabric8/openshift/api/model/PlatformSpecBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class PlatformSpecBuilder extends io.fabric8.openshift.api.model.PlatformSpecFluentImpl<io.fabric8.openshift.api.model.PlatformSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.PlatformSpec,io.fabric8.openshift.api.model.PlatformSpecBuilder>{
  public PlatformSpecBuilder() {
    this(false);
  }
  public PlatformSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new PlatformSpec(), validationEnabled);
  }
  public PlatformSpecBuilder(io.fabric8.openshift.api.model.PlatformSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public PlatformSpecBuilder(io.fabric8.openshift.api.model.PlatformSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new PlatformSpec(), validationEnabled);
  }
  public PlatformSpecBuilder(io.fabric8.openshift.api.model.PlatformSpecFluent<?> fluent,io.fabric8.openshift.api.model.PlatformSpec instance) {
    this(fluent, instance, false);
  }
  public PlatformSpecBuilder(io.fabric8.openshift.api.model.PlatformSpecFluent<?> fluent,io.fabric8.openshift.api.model.PlatformSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAlibabaCloud(instance.getAlibabaCloud()); 
    fluent.withAws(instance.getAws()); 
    fluent.withAzure(instance.getAzure()); 
    fluent.withBaremetal(instance.getBaremetal()); 
    fluent.withEquinixMetal(instance.getEquinixMetal()); 
    fluent.withGcp(instance.getGcp()); 
    fluent.withIbmcloud(instance.getIbmcloud()); 
    fluent.withKubevirt(instance.getKubevirt()); 
    fluent.withOpenstack(instance.getOpenstack()); 
    fluent.withOvirt(instance.getOvirt()); 
    fluent.withPowervs(instance.getPowervs()); 
    fluent.withType(instance.getType()); 
    fluent.withVsphere(instance.getVsphere()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public PlatformSpecBuilder(io.fabric8.openshift.api.model.PlatformSpec instance) {
    this(instance,false);
  }
  public PlatformSpecBuilder(io.fabric8.openshift.api.model.PlatformSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAlibabaCloud(instance.getAlibabaCloud()); 
    this.withAws(instance.getAws()); 
    this.withAzure(instance.getAzure()); 
    this.withBaremetal(instance.getBaremetal()); 
    this.withEquinixMetal(instance.getEquinixMetal()); 
    this.withGcp(instance.getGcp()); 
    this.withIbmcloud(instance.getIbmcloud()); 
    this.withKubevirt(instance.getKubevirt()); 
    this.withOpenstack(instance.getOpenstack()); 
    this.withOvirt(instance.getOvirt()); 
    this.withPowervs(instance.getPowervs()); 
    this.withType(instance.getType()); 
    this.withVsphere(instance.getVsphere()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.PlatformSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.PlatformSpec build() {
    PlatformSpec buildable = new PlatformSpec(fluent.getAlibabaCloud(),fluent.getAws(),fluent.getAzure(),fluent.getBaremetal(),fluent.getEquinixMetal(),fluent.getGcp(),fluent.getIbmcloud(),fluent.getKubevirt(),fluent.getOpenstack(),fluent.getOvirt(),fluent.getPowervs(),fluent.getType(),fluent.getVsphere());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PlatformSpecBuilder that = (PlatformSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
